@@ -1180,6 +1180,7 @@ config_scan_pem_dir(char *pemdir, hitch_config *cfg)
 	int n, i, plen;
 	int retval = 0;
 	struct dirent **d;
+	struct stat st;
 
 	n = scandir(pemdir, &d, NULL, alphasort);
 	if (n < 0) {
@@ -1197,20 +1198,34 @@ config_scan_pem_dir(char *pemdir, hitch_config *cfg)
 			if (fnmatch(cfg->PEM_DIR_GLOB, d[i]->d_name, 0))
 				continue;
 		}
-		if (d[i]->d_type != DT_REG)
+		if (d[i]->d_type != DT_UNKNOWN && d[i]->d_type != DT_REG)
 			continue;
 
 		fpath = malloc(plen);
 		AN(fpath);
 
 		if (snprintf(fpath, plen, "%s%s", pemdir, d[i]->d_name) < 0) {
-			config_error_set("An error occured while "
+			config_error_set("An error occurred while "
 			    "combining path");
 			free(fpath);
 			retval = 1;
 			break;
 		}
 
+		if (d[i]->d_type == DT_UNKNOWN) {
+			/* The underlying filesystem does not support d_type. */
+			if (lstat(fpath, &st) < 0) {
+				fprintf(stderr, "Warning: unable to stat '%s': %s. Skipping.\n",
+				    fpath, strerror(errno));
+				free(fpath);
+				continue;
+			}
+			if (!S_ISREG(st.st_mode)) {
+				free(fpath);
+				continue;
+			}
+		}
+
 		cert = cfg_cert_file_new();
 		config_assign_str(&cert->filename, fpath);
 		free(fpath);
@@ -1257,7 +1272,7 @@ config_print_usage_fd(char *prog, FILE *out)
 	fprintf(out, "\t--tls-protos=LIST\n");
 	fprintf(out, "\t\tSpecifies which SSL/TLS protocols to use.\n");
 	fprintf(out, "\t\tAvailable tokens are SSLv3, TLSv1.0, TLSv1.1\n");
-	fprintf(out, "\t\tTLSv1.2 and TLSv1.3. (Default: \"TLSv1.2 TLSv1.3\"\n)");
+	fprintf(out, "\t\tTLSv1.2 and TLSv1.3. (Default: \"TLSv1.2 TLSv1.3\")\n");
 	fprintf(out, "\t-c  --ciphers=SUITE\n");
 	fprintf(out, "\t\tSets allowed ciphers (Default: \"%s\")\n",
 	    config_disp_str(cfg->CIPHERS_TLSv12));
